@@ -1,10 +1,12 @@
 use std::collections::HashMap;
 use std::io::Error;
-use streamduck_daemon::socket::daemon_data::{AddDeviceResult, Device, GetDeviceResult, ReloadDeviceConfigResult, ReloadDeviceConfigsResult, RemoveDeviceResult, SaveDeviceConfigResult, SaveDeviceConfigsResult, SetBrightnessResult};
+use streamduck_core::core::button::Button;
+use streamduck_core::core::RawButtonPanel;
+use streamduck_daemon::socket::daemon_data::{AddDeviceResult, ClearButtonResult, CommitChangesToConfigResult, Device, GetButtonResult, GetCurrentScreenResult, GetDeviceResult, GetStackResult, PopScreenResult, PushScreenResult, ReloadDeviceConfigResult, ReloadDeviceConfigsResult, RemoveDeviceResult, ReplaceScreenResult, ResetStackResult, SaveDeviceConfigResult, SaveDeviceConfigsResult, SetBrightnessResult, SetButtonResult};
 
 pub use streamduck_daemon as daemon;
-use streamduck_daemon::modules::components::ComponentDefinition;
-use streamduck_daemon::modules::PluginMetadata;
+use streamduck_core::modules::components::ComponentDefinition;
+use streamduck_core::modules::PluginMetadata;
 use streamduck_daemon::socket::SocketError;
 
 #[cfg(target_family = "unix")]
@@ -44,6 +46,30 @@ pub trait SDClient {
     fn list_modules(&self) -> Result<Vec<PluginMetadata>, SDClientError>;
     /// Lists all components that were introduced by modules
     fn list_components(&self) -> Result<HashMap<String, HashMap<String, ComponentDefinition>>, SDClientError>;
+
+    // Panel management
+    /// Gets stack of a device
+    fn get_stack(&self, serial_number: &str) -> Result<GetStackResult, SDClientError>;
+    /// Gets current screen of a device
+    fn get_current_screen(&self, serial_number: &str) -> Result<GetCurrentScreenResult, SDClientError>;
+    /// Gets a button from current screen of a device
+    fn get_button(&self, serial_number: &str, key: u8) -> Result<GetButtonResult, SDClientError>;
+    /// Sets a button on current screen of a device
+    fn set_button(&self, serial_number: &str, key: u8, button: Button) -> Result<SetButtonResult, SDClientError>;
+    /// Clears a button from current screen of a device
+    fn clear_button(&self, serial_number: &str, key: u8) -> Result<ClearButtonResult, SDClientError>;
+    /// Pushes a new screen on a device
+    fn push_screen(&self, serial_number: &str, screen: RawButtonPanel) -> Result<PushScreenResult, SDClientError>;
+    /// Pops a screen from a device
+    fn pop_screen(&self, serial_number: &str) -> Result<PopScreenResult, SDClientError>;
+    /// Replaces current screen on a device
+    fn replace_screen(&self, serial_number: &str, screen: RawButtonPanel) -> Result<ReplaceScreenResult, SDClientError>;
+    /// Resets stack and sets provided screen as root screen
+    fn reset_stack(&self, serial_number: &str, screen: RawButtonPanel) -> Result<ResetStackResult, SDClientError>;
+    /// Commits all changes to stack to device config, should be called after each change/sequence of changes, otherwise all changes will be lost on reconnect
+    fn commit_changes(&self, serial_number: &str) -> Result<CommitChangesToConfigResult, SDClientError>;
+
+    // TODO: Custom requests support
 }
 
 /// Errors that could happen with the client
