@@ -4,10 +4,14 @@ use std::os::unix::net::UnixStream;
 use std::sync::{Arc, RwLock};
 use serde::{Serialize};
 use serde::de::DeserializeOwned;
-use streamduck_daemon::socket::daemon_data::{AddDevice, AddDeviceResult, Device, ListDevices, GetDevice, GetDeviceResult, RemoveDevice, RemoveDeviceResult, SocketAPIVersion, ReloadDeviceConfigsResult, ReloadDeviceConfigResult, SaveDeviceConfigsResult, SaveDeviceConfigResult, SetBrightnessResult, ReloadDeviceConfig, SaveDeviceConfig, SetBrightness, ListModules, ListComponents};
+use streamduck_core::core::button::Button;
+use streamduck_core::core::RawButtonPanel;
+use streamduck_core::modules::components::ComponentDefinition;
+use streamduck_core::modules::PluginMetadata;
+use streamduck_core::versions::SOCKET_API;
+use streamduck_daemon::socket::daemon_data::{AddDevice, AddDeviceResult, Device, ListDevices, GetDevice, GetDeviceResult, RemoveDevice, RemoveDeviceResult, SocketAPIVersion, ReloadDeviceConfigsResult, ReloadDeviceConfigResult, SaveDeviceConfigsResult, SaveDeviceConfigResult, SetBrightnessResult, ReloadDeviceConfig, SaveDeviceConfig, SetBrightness, ListModules, ListComponents, GetButtonResult, SetButtonResult, ClearButtonResult, PushScreenResult, PopScreenResult, ReplaceScreenResult, ResetStackResult, CommitChangesToConfigResult, GetStackResult, GetCurrentScreenResult, GetStack, GetCurrentScreen, GetButton, SetButton, ClearButton, PushScreen, PopScreen, ReplaceScreen, ResetStack, CommitChangesToConfig};
 use streamduck_daemon::socket::{parse_packet_to_data, send_no_data_packet_with_requester, send_packet_with_requester, SocketData, SocketPacket};
-use streamduck_daemon::versions::SOCKET_API;
-use crate::{ComponentDefinition, PluginMetadata, SDClient, SDClientError};
+use crate::{SDClient, SDClientError};
 
 /// Definition of Unix Socket based client
 pub struct UnixClient {
@@ -143,4 +147,91 @@ impl SDClient for UnixClient {
 
         Ok(response.components)
     }
+
+    fn get_stack(&self, serial_number: &str) -> Result<GetStackResult, SDClientError> {
+        let response: GetStackResult = self.process_request(&GetStack {
+            serial_number: serial_number.to_string()
+        })?;
+
+        Ok(response)
+    }
+
+    fn get_current_screen(&self, serial_number: &str) -> Result<GetCurrentScreenResult, SDClientError> {
+        let response: GetCurrentScreenResult = self.process_request(&GetCurrentScreen {
+            serial_number: serial_number.to_string()
+        })?;
+
+        Ok(response)
+    }
+
+    fn get_button(&self, serial_number: &str, key: u8) -> Result<GetButtonResult, SDClientError> {
+        let response: GetButtonResult = self.process_request(&GetButton {
+            serial_number: serial_number.to_string(),
+            key
+        })?;
+
+        Ok(response)
+    }
+
+    fn set_button(&self, serial_number: &str, key: u8, button: Button) -> Result<SetButtonResult, SDClientError> {
+        let response: SetButtonResult = self.process_request(&SetButton {
+            serial_number: serial_number.to_string(),
+            key,
+            button
+        })?;
+
+        Ok(response)
+    }
+
+    fn clear_button(&self, serial_number: &str, key: u8) -> Result<ClearButtonResult, SDClientError> {
+        let response: ClearButtonResult = self.process_request(&ClearButton {
+            serial_number: serial_number.to_string(),
+            key
+        })?;
+
+        Ok(response)
+    }
+
+    fn push_screen(&self, serial_number: &str, screen: RawButtonPanel) -> Result<PushScreenResult, SDClientError> {
+        let response: PushScreenResult = self.process_request(&PushScreen {
+            serial_number: serial_number.to_string(),
+            screen
+        })?;
+
+        Ok(response)
+    }
+
+    fn pop_screen(&self, serial_number: &str) -> Result<PopScreenResult, SDClientError> {
+        let response: PopScreenResult = self.process_request(&PopScreen {
+            serial_number: serial_number.to_string()
+        })?;
+
+        Ok(response)
+    }
+
+    fn replace_screen(&self, serial_number: &str, screen: RawButtonPanel) -> Result<ReplaceScreenResult, SDClientError> {
+        let response: ReplaceScreenResult = self.process_request(&ReplaceScreen {
+            serial_number: serial_number.to_string(),
+            screen
+        })?;
+
+        Ok(response)
+    }
+
+    fn reset_stack(&self, serial_number: &str, screen: RawButtonPanel) -> Result<ResetStackResult, SDClientError> {
+        let response: ResetStackResult = self.process_request(&ResetStack {
+            serial_number: serial_number.to_string(),
+            screen
+        })?;
+
+        Ok(response)
+    }
+
+    fn commit_changes(&self, serial_number: &str) -> Result<CommitChangesToConfigResult, SDClientError> {
+        let response: CommitChangesToConfigResult = self.process_request(&CommitChangesToConfig {
+            serial_number: serial_number.to_string()
+        })?;
+
+        Ok(response)
+    }
 }
\ No newline at end of file
